@@ -5,7 +5,7 @@ use strict;
 use warnings;
 no autovivification;
 
-use version; our $VERSION = qv('v1.6.0');
+use version; our $VERSION = qv('v1.8.0');
 
 
 use Time::HiRes                              qw( );
@@ -334,10 +334,10 @@ sub _projects {
 
    my %form;
    for my $field_name (
-      'category',           # Category's "id", "slug" or "name".
-      'location',           # Location's "id" (which is a "Where on Earth Identifier").
-      'sort',               # 'magic' (default), 'end_date', 'newest', 'launch_date', 'popularity', 'most_funded'
       'q',                  # Search terms
+      'category',           # Category's "id", "slug" or "name".
+      'tag',                # Tag's "id" or "slug".
+      'location',           # Location's "id" (which is a "Where on Earth Identifier").
       'backed_by_self',     # Boolean
       'starred_by_self',    # Boolean
       'backed_by_friends',  # Boolean
@@ -346,23 +346,21 @@ sub _projects {
       'pledged',            # 'all' (default), '0':<$10k, '1':$10k to $100k, '2':$100k to $1M, '3':>$1M
       'goal',               # 'all' (default), '0':<$10k, '1':$10k to $100k, '2':$100k to $1M, '3':>$1M
       'raised',             # 'all' (default), '0':<75%, '1':75% to 100%, '2':>100%
-      'tag',                # Tag's "id" or "slug".
+      'sort',               # 'magic' (default), 'end_date', 'newest', 'launch_date', 'popularity', 'most_funded'
    ) {
       $form{$field_name} = exists($fixed->{$field_name}) ? $fixed->{$field_name} : delete($opts{$field_name});
    }
 
-   $form{category} = ''      if !defined($form{category});
-   $form{location} = ''      if !defined($form{location});
-   $form{sort}     = 'magic' if !defined($form{sort})        || !length($form{sort});
    $form{q}        = ''      if !defined($form{q});
+   $form{category} = ''      if !defined($form{category});
+   $form{tag}      = ''      if !defined($form{tag});
+   $form{location} = ''      if !defined($form{location});
    $form{state}    = 'all'   if !defined($form{state})       || !length($form{state});
    $form{pledged}  = 'all'   if !defined($form{pledged})     || !length($form{pledged});
    $form{goal}     = 'all'   if !defined($form{goal})        || !length($form{goal});
    $form{raised}   = 'all'   if !defined($form{raised})      || !length($form{raised});
-   $form{tag}      = ''      if !defined($form{tag});
+   $form{sort}     = 'magic' if !defined($form{sort})        || !length($form{sort});
 
-   $form{sort} =~ /^(?:magic|end_date|newest|launch_date|popularity|most_funded)\z/
-      or my_croak(400, "Unrecognized value for sort. Valid: magic, end_date, newest, launch_date, popularity, most_funded");
    $form{state} =~ /^(?:all|live|successful)\z/
       or my_croak(400, "Unrecognized value for state. Valid: all, live, successful");
    $form{pledged} =~ /^(?:all|[0123])\z/
@@ -371,12 +369,14 @@ sub _projects {
       or my_croak(400, "Unrecognized value for goal. Valid: all, 0, 1, 2, 3");
    $form{raised} =~ /^(?:all|[012])\z/
       or my_croak(400, "Unrecognized value for raised. Valid: all, 0, 1, 2");
+   $form{sort} =~ /^(?:magic|end_date|newest|launch_date|popularity|most_funded)\z/
+      or my_croak(400, "Unrecognized value for sort. Valid: magic, end_date, newest, launch_date, popularity, most_funded");
 
    my $url = URI->new('discover', 'http');
-   $url->query_param_append( category_id => $form{category} ) if length($form{category});
-   $url->query_param_append( woe_id      => $form{location} ) if length($form{location});
-   $url->query_param_append( sort        => $form{sort}     ) if $form{sort} ne 'magic';
    $url->query_param_append( term        => $form{q}        ) if length($form{q});
+   $url->query_param_append( category_id => $form{category} ) if length($form{category});
+   $url->query_param_append( tag_id      => $form{tag}      ) if length($form{tag});
+   $url->query_param_append( woe_id      => $form{location} ) if length($form{location});
    $url->query_param_append( backed      => '1'             ) if $form{backed_by_self};
    $url->query_param_append( starred     => '1'             ) if $form{starred_by_self};
    $url->query_param_append( social      => '1'             ) if $form{backed_by_friends};
@@ -385,7 +385,7 @@ sub _projects {
    $url->query_param_append( pledged     => $form{pledged}  ) if $form{pledged} ne 'all';
    $url->query_param_append( goal        => $form{goal}     ) if $form{goal}    ne 'all';
    $url->query_param_append( raised      => $form{raised}   ) if $form{raised}  ne 'all';
-   $url->query_param_append( tag_id      => $form{tag}      ) if length($form{tag});
+   $url->query_param_append( sort        => $form{sort}     ) if $form{sort} ne 'magic';
 
    return $self->_call_api($url, [ 'iterator', cursor_style=>'page' ], 'Project', %opts);
 }
@@ -433,7 +433,7 @@ sub my_projects_backed {
 
 # There's no way to have 'discover?starred=1' return the results sorted by starring timestamp,
 # so we'll continue to use the original interface ('users/self/projects/starred').
-# But for consistency and possibly for foward-compatibility, we'll require a page-style cursor.
+# But for consistency and possibly for forward-compatibility, we'll require a page-style cursor.
 sub my_projects_starred {
    my ($self, %opts) = @_;
 
@@ -444,6 +444,7 @@ sub my_projects_starred {
    if (defined(my $page = delete($opts{page}))) {
       $opts{start} = ($page - 1) * 10;
    }
+
    return $self->_call_api('users/self/projects/starred', [ 'iterator', cursor_style=>'start' ], 'Project', %opts);
 }
 
@@ -556,7 +557,7 @@ WWW::Kickstarter - Retrieve information from Kickstarter
 
 =head1 VERSION
 
-Version 1.6.0
+Version 1.8.0
 
 
 =head1 SYNOPSIS
@@ -578,7 +579,7 @@ Version 1.6.0
 =head1 DESCRIPTION
 
 This distribution provides access to Kickstarter's private API
-to obtain information about your account, other users and and projects.
+to obtain information about your account, other users and projects.
 
 
 =head1 CONSTRUCTOR
@@ -762,9 +763,9 @@ Options:
 
 =over
 
-=item * C<< page => $page_num >>
+=item * C<< q => $search_terms >>
 
-If provided, the pages of results before the specified page number are skipped.
+Limits the projects returned to those matching the string of search terms.
 
 =item * C<< category => $category_id >>
 
@@ -774,35 +775,169 @@ If provided, the pages of results before the specified page number are skipped.
 
 Limits the projects returned to those of the specified category (or one of its subcategories).
 
+=item * C<< tag => $tag_id >>
+
+=item * C<< tag => $tag_slug >>
+
+Limits the projects returned to those with the specified tag.
+
+I don't know of an API endpoint that returns a list of available tags. The following are the tags that exist at the time of this writing:
+
+=over
+
+=item * At Home (id: 131, slug: at-home)
+
+=item * Avant-Garde (id: 138, slug: avant-garde)
+
+=item * Burning Man (id: 34, slug: burning-man)
+
+=item * Carpe Noctem (id: 174, slug: carpe-noctem)
+
+=item * Compelling Stories (id: 120, slug: compelling-stories)
+
+=item * Creative Spaces (id: 78, slug: creative-spaces)
+
+=item * DIY (id: 5, slug: diy)
+
+=item * Dapper (id: 135, slug: dapper)
+
+=item * Fantasy (id: 133, slug: fantasy)
+
+=item * Fringe (id: 99, slug: fringe)
+
+=item * Go Green (id: 121, slug: go-green)
+
+=item * Innovative (id: 128, slug: innovative)
+
+=item * Inspirational (id: 123, slug: inspirational)
+
+=item * Kids (id: 86, slug: kids)
+
+=item * LOL (id: 105, slug: lol)
+
+=item * Let's Eat (id: 118, slug: lets-eat)
+
+=item * Library (id: 46, slug: library)
+
+=item * Maker (id: 10, slug: hacker-maker)
+
+=item * Monsters (id: 30, slug: zombies) [Formerly named "Zombies"]
+
+=item * Museums (id: 63, slug: museums)
+
+=item * Open Source (id: 20, slug: open-source)
+
+=item * Preserve and Restore (id: 110, slug: conservation)
+
+=item * Print It (id: 77, slug: print-it)
+
+=item * Public Benefit (id: 3, slug: public-benefit) [Formerly named "Civic", with slug "civic"]
+
+=item * Ride With It (id: 50, slug: bikes) [Formerly named "Bikes"]
+
+=item * Robots (id: 41, slug: robots)
+
+=item * Sci-Fi (id: 139, slug: sci-fi)
+
+=item * Science (id: 19, slug: science)
+
+=item * Space (id: 28, slug: space)
+
+=item * Standout Style (id: 136, slug: standout-style)
+
+=item * Turn It Up (id: 132, slug: audiophiles)
+
+=item * World Explorers (id: 126, slug: world-explorers)
+
+=back
+
+The following are also tags that are known to exist, but these aren't shown on the website. It's possible they aren't actively used anymore.
+
+=over
+
+=item * Add To It (id: 127, slug: add-to-it)
+
+=item * Always Be Learning (id: 74, slug: education)
+
+=item * Animal Kingdom (id: 1, slug: animal-kingdom)
+
+=item * Artisanal (id: 122, slug: artisanal)
+
+=item * Dance Films (id: 189, slug: dance-films)
+
+=item * Great GIFs (id: 175, slug: great-gifs)
+
+=item * Great Gifts (id: 129, slug: great-gifts)
+
+=item * Health Nuts (id: 130, slug: health-nuts)
+
+=item * Integrity Pick (id: 176, slug: integrity-pick)
+
+=item * It's History (id: 125, slug: its-history)
+
+=item * Maps (id: 48, slug: maps)
+
+=item * Movers and Shakers (id: 124, slug: movers-and-shakers)
+
+=item * Net Culture (id: 119, slug: net-culture)
+
+=item * Projects We Love (id: 115, slug: projects-we-love)
+
+=item * Punk (id: 134, slug: punk)
+
+=item * Retro (id: 22, slug: retro)
+
+=item * RPG (id: 33, slug: rpg)
+
+=item * See It Live (id: 137, slug: see-it-live)
+
+=item * Trailers (id: 187, slug: trailers)
+
+=back
+
+=begin comment
+
+The following are known to have existed at some time, but are no longer recognized:
+
+=over
+
+=item * Arctic (id: 39, slug: arctic)
+
+=item * Cats (id: 31, slug: cats)
+
+=item * Cthulhu (id: 38, slug: cthulhu)
+
+=item * Maker Faire (id: 87, slug: maker-faire)
+
+=item * Movie Theater (id: 43, slug: movie-theater)
+
+=item * Space is the Place (id: 107, slug: space-is-the-place)
+
+=item * Sundance (id: 29, slug: sundance)
+
+=item * World Maker Faire 2014 (id: 106, slug: world-maker-faire-2014)
+
+=back
+
+=end comment
+
+The first list was obtained from L<Kickstarter's Advanced Discover page|https://www.kickstarter.com/discover/advanced>. The second list was obtained through trial and error.
+
 =item * C<< location => $woe_id >>
 
 Limits the projects returned to those associated with the specified location.
 
-=item * C<< sort => 'magic' >> (default)
-
-=item * C<< sort => 'end_date' >>
-
-=item * C<< sort => 'newest' >>
-
-=item * C<< sort => 'launch_date' >>
-
-=item * C<< sort => 'popularity' >>
-
-=item * C<< sort => 'most_funded' >>
-
-Controls the order in which the projects are returned.
-
 =item * C<< backed_by_self => 1 >>
 
-Limits the projects returned to those the logged-in user backed.
+Limits the projects returned to those backed by the logged-in user.
 
 =item * C<< starred_by_self => 1 >>
 
-Limits the projects returned to those the logged-in user starred.
+Limits the projects returned to those starred by the logged-in user.
 
 =item * C<< backed_by_friends => 1 >>
 
-Limits the projects returned to those friends of the logged-in user backed.
+Limits the projects returned to those backed by friends of the logged-in user.
 
 =item * C<< picked_by_staff => 1 >>
 
@@ -868,69 +1003,23 @@ Limits the projects returned to those to which the amount pledged falls within t
 
 The empty string and the string C<all> are accepted as equivalent to not providing the option at all.
 
-=item * C<< tag => $tag_id >>
+=item * C<< sort => 'magic' >> (default)
 
-=item * C<< tag => $tag_slug >>
+=item * C<< sort => 'end_date' >>
 
-Limits the projects returned to those with the specified tag.
+=item * C<< sort => 'newest' >>
 
-I don't know of an API endpoint that returns a list of available tags. The following are the tags that exist at the time of this writing:
+=item * C<< sort => 'launch_date' >>
 
-=over
+=item * C<< sort => 'popularity' >>
 
-=item * Bikes (id: 50, slug: bikes)
+=item * C<< sort => 'most_funded' >>
 
-=item * Burning Man (id: 34, slug: burning-man)
+Controls the order in which the projects are returned.
 
-=item * Cats (id: 31, slug: cats)
+=item * C<< page => $page_num >>
 
-=item * Civic (id: 3, slug: civic)
-
-=item * Cthulhu (id: 38, slug: cthulhu)
-
-=item * Fringe (id: 99, slug: fringe)
-
-=item * Library (id: 46, slug: library)
-
-=item * LOL (id: 105, slug: lol)
-
-=item * Maps (id: 48, slug: maps)
-
-=item * Movie Theater (id: 43, slug: movie-theater)
-
-=item * Museums (id: 63, slug: museums)
-
-=item * Open source (id: 20, slug: open-source)
-
-=item * Robots (id: 41, slug: robots)
-
-=item * Science (id: 19, slug: science)
-
-=item * Space is the Place (id: 107, slug: space-is-the-place)
-
-=item * World Maker Faire 2014 (id: 106, slug: world-maker-faire-2014)
-
-=back
-
-The following are also tags that are known to exist, but these aren't shown on the website. It's possible they aren't actively used anymore.
-
-=over
-
-=item * Arctic (id: 39, slug: arctic)
-
-=item * Maker Faire (id: 87, slug: maker-faire)
-
-=item * RPG (id: 33, slug: rpg)
-
-=item * Space (id: 28, slug: space)
-
-=item * Sundance (id: 29, slug: sundance)
-
-=item * Zombies (id: 30, slug: zombies)
-
-=back
-
-The first list was obtained from L<Kickstarter's Advanced Discover page|https://www.kickstarter.com/discover/advanced>. The second list was obtained through trial and error.
+If provided, the pages of results before the specified page number are skipped.
 
 =back
 
@@ -1045,7 +1134,7 @@ It accepts the same options as L<C<projects>|/projects>.
 When an API call encounters an error, it throws a L<WWW::Kickstarter::Error> object as an exception.
 
 
-=head1 GARANTEE
+=head1 GUARANTEE
 
 Kickstarter has not provided a public API. As such,
 this distribution uses a private API to obtain information.
@@ -1075,43 +1164,64 @@ The following issues are known:
 Feel free to bug me (C<< <ikegami@adaelis.com> >>) to work on these, or to submit a patch to the bug tracker.
 
 
-=head1 SUPPORT
+=head1 DOCUMENTATION AND SUPPORT
 
 You can find documentation for this module with the perldoc command.
 
    perldoc WWW::Kickstarter
 
-You can also look for information at:
+You can also find it online at these locations:
 
 =over
 
-=item * Search CPAN
+=item * L<http://search.cpan.org/dist/WWW-Kickstarter>
 
-L<http://search.cpan.org/dist/WWW-Kickstarter>
+=item * L<https://metacpan.org/release/WWW-Kickstarter>
 
-=item * RT: CPAN's request tracker
+=back
 
-L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=WWW-Kickstarter>
+If you need help, the following are great resources:
 
-=item * AnnoCPAN: Annotated CPAN documentation
+=over
 
-L<http://annocpan.org/dist/WWW-Kickstarter>
+=item * L<https://stackoverflow.com/|StackOverflow>
 
-=item * CPAN Ratings
+=item * L<http://www.perlmonks.org/|PerlMonks>
 
-L<http://cpanratings.perl.org/d/WWW-Kickstarter>
+=item * You may also contact the author directly.
+
+=back
+
+Bugs and improvements can be reported using either of the following systems:
+
+=over
+
+=item Using CPAN's request tracker at L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=WWW-Kickstarter>
+
+=item Using GitHub's issue tracker at L<https://github.com/ikegami/perl-WWW-Kickstarter/issues>
 
 =back
 
 
-=head1 AUTHORS
+=head1 REPOSITORY
 
-Eric Brine, C<< <ikegami@adaelis.com> >>
+=over
+
+=item * Web: L<https://github.com/ikegami/perl-WWW-Kickstarter>
+
+=item * git: L<https://github.com/ikegami/perl-WWW-Kickstarter.git>
+
+=back
+
+
+=head1 AUTHOR
+
+Eric Brine C<< <ikegami@adaelis.com> >>
 
 Initial release assisted by Mark Olson's "Kickscraper" project for Ruby.
 
 
-=head1 COPYRIGHT & LICENSE
+=head1 COPYRIGHT AND LICENSE
 
 No rights reserved.
 
